/*-
 * Copyright (c) 2007 Benedikt Stockebrand
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#include <sys/socket.h>
#include <string.h>
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <syslog.h>
#include <unistd.h>

#include "tcp_server.h"

#define MESSAGE        "Hello, client!\n"
#define MESSAGE_LENGTH strlen(MESSAGE)

void handle_request(int sockd,
		    struct sockaddr * clt_sa,
		    socklen_t         clt_sa_len)
{
  char remotehost[NI_MAXHOST];
  char remoteport[NI_MAXSERV];
  int  status;

  status = getnameinfo(clt_sa, clt_sa_len,
		       remotehost, NI_MAXHOST,
		       remoteport, NI_MAXSERV,
		       NI_NUMERICHOST | NI_NUMERICSERV);
  if (status)
    syslog(LOG_ERR, "getnameinfo(3): %s",
	   gai_strerror(status));

  syslog(LOG_INFO, "Incoming connection: [%s]:%s",
	 remotehost, remoteport);

  write(sockd, MESSAGE, MESSAGE_LENGTH);
  
}




int main(int argc, char * argv[])
{
  if (argc !=2) {
    fprintf(stderr,
            "Usage: %s <port/service name>\n",
	    argv[0]);
    exit(EXIT_FAILURE);
  }
  tcp_server(argv[1], NULL, handle_request);

  return 0;
}

/* Local Variables:
eval: (c-set-style "gnu")
eval: (set-fill-column 50)
*/
